@@ -103,7 +103,11 @@ namespace KCDDB
     uint
   CDDB::statusCode( const QString & line )
   {
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     QStringList tokenList = line.split(QLatin1Char( ' ' ), QString::SkipEmptyParts );
+#else
+    QStringList tokenList = line.split(QLatin1Char( ' ' ), Qt::SkipEmptyParts );
+#endif
 
     uint serverStatus = tokenList[ 0 ].toUInt();
 
